@@ -1,17 +1,15 @@
 package Map::Tube::Bucharest;
 
-# Pragmas.
 use strict;
 use warnings;
 use 5.006;
 
-# Modules.
 use File::Share ':all';
 use Moo;
 use namespace::clean;
 
 # Version.
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 
 # Get XML.
 has xml => (
@@ -36,6 +34,7 @@ Map::Tube::Bucharest - Interface to the Bucharest Metro Map.
 =head1 SYNOPSIS
 
  use Map::Tube::Bucharest;
+
  my $obj = Map::Tube::Bucharest->new;
  my $routes_ar = $obj->get_all_routes($from, $to);
  my $line = $obj->get_line_by_id($line_id);
@@ -117,11 +116,9 @@ For more information about Bucharest Map, click L<here|https://en.wikipedia.org/
 
 =head1 EXAMPLE1
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Encode qw(decode_utf8 encode_utf8);
  use Map::Tube::Bucharest;
 
@@ -139,12 +136,10 @@ For more information about Bucharest Map, click L<here|https://en.wikipedia.org/
 
 =head1 EXAMPLE2
 
- # Pragmas.
  use strict;
  use utf8;
  use warnings;
 
- # Modules.
  use Map::Tube::Bucharest;
 
  # Object.
@@ -161,11 +156,9 @@ For more information about Bucharest Map, click L<here|https://en.wikipedia.org/
 
 =head1 EXAMPLE3
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Map::Tube::GraphViz;
  use Map::Tube::GraphViz::Utils qw(node_color_without_label);
  use Map::Tube::Bucharest;
@@ -191,19 +184,17 @@ For more information about Bucharest Map, click L<here|https://en.wikipedia.org/
 
 =begin html
 
-<a href="https://raw.githubusercontent.com/tupinek/Map-Tube-Bucharest/master/images/ex3.png">
-  <img src="https://raw.githubusercontent.com/tupinek/Map-Tube-Bucharest/master/images/ex3.png" alt="Metroul din București" width="300px" height="300px" />
+<a href="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-Bucharest/master/images/ex3.png">
+  <img src="https://raw.githubusercontent.com/michal-josef-spacek/Map-Tube-Bucharest/master/images/ex3.png" alt="Metroul din București" width="300px" height="300px" />
 </a>
 
 =end html
 
 =head1 EXAMPLE4
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Encode qw(encode_utf8);
  use Map::Tube::Bucharest;
 
@@ -224,11 +215,9 @@ For more information about Bucharest Map, click L<here|https://en.wikipedia.org/
 
 =head1 EXAMPLE5
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Encode qw(encode_utf8);
  use Map::Tube::Bucharest;
 
@@ -289,7 +278,7 @@ Install the Map::Tube concrete metro modules.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Map-Tube-Bucharest>
+L<https://github.com/michal-josef-spacek/Map-Tube-Bucharest>
 
 =head1 AUTHOR
 
@@ -299,12 +288,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014-2017 Michal Josef Špaček
+ © 2014-2020 Michal Josef Špaček
  Artistic License
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.09
+0.10
 
 =cut
